tlslite.errors.TLSAuthenticationError

Package tlslite :: Module errors :: Class TLSAuthenticationError |
[show private | hide private]
[frames | no frames]

## Class TLSAuthenticationError

    Exception --+
                |
         TLSError --+
                    |
                   TLSAuthenticationError

Known Subclasses:
  `TLSAuthenticationTypeError`, `TLSAuthorizationError`, `TLSFingerprintError`, `TLSNoAuthenticationError`, `TLSValidationError`

The handshake succeeded, but the other party's authentication was inadequate.

This exception will only be raised when a `tlslite.Checker.Checker` has been passed to a handshake function. The Checker will be invoked once the handshake completes, and if the Checker objects to how the other party authenticated, a subclass of this exception will be raised.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net